package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcCy;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcXtjc;
import com.ruoyi.tcZz.service.ITcXtjcService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 系统监测Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@Api(tags = "系统监测")
@RestController
@RequestMapping("/tcZz/networkSecurity/xtjc")
public class TcXtjcController extends BaseController {
    @Autowired
    private ITcXtjcService tcXtjcService;

    /**
     * 查询系统监测列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:xtjc:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcXtjc tcXtjc) {
        startPage();
        List<TcXtjc> list = tcXtjcService.selectTcXtjcList(tcXtjc);
        return getDataTable(list);
    }

    /**
     * 导出系统监测列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:xtjc:export')")
    @Log(title = "系统监测", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcXtjc tcXtjc) {
        List<TcXtjc> list = tcXtjcService.selectTcXtjcList(tcXtjc);
        ExcelUtil<TcXtjc> util = new ExcelUtil<TcXtjc>(TcXtjc.class);
        util.exportExcel(response, list, "系统监测数据");
    }

    /**
     * 获取系统监测详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:xtjc:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcXtjcService.selectTcXtjcById(id));
    }

    /**
     * 新增系统监测
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:xtjc:add')")
    @Log(title = "系统监测", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcXtjc tcXtjc) {
        return toAjax(tcXtjcService.insertTcXtjc(tcXtjc));
    }

    /**
     * 修改系统监测
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:xtjc:edit')")
    @Log(title = "系统监测", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcXtjc tcXtjc) {
        return toAjax(tcXtjcService.updateTcXtjc(tcXtjc));
    }

    /**
     * 删除系统监测
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:xtjc:remove')")
    @Log(title = "系统监测", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcXtjcService.deleteTcXtjcByIds(ids));
    }


    /**
     * 查询系统监测列表
     */
    @ApiOperation(value = "查询系统监测列表", response = TcXtjc.class)
    @GetMapping("/ListNoToken")
    public TableDataInfo ListNoToken(TcXtjc tcXtjc) {
        startPage();
        List<TcXtjc> list = tcXtjcService.selectTcXtjcList(tcXtjc);
        return getDataTable(list);
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcXtjc> util = new ExcelUtil<TcXtjc>(TcXtjc.class);
        List<TcXtjc> tcXtjcList = util.importExcel(file.getInputStream());
        tcXtjcService.importUser(tcXtjcList);
        return AjaxResult.success();
    }
}
