package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcZxyh;
import com.ruoyi.tcZz.service.ITcZxyhService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 最新隐患Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@RequestMapping("/tcZz/networkSecurity/zxyh")
public class TcZxyhController extends BaseController
{
    @Autowired
    private ITcZxyhService tcZxyhService;

    /**
     * 查询最新隐患列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zxyh:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcZxyh tcZxyh)
    {
        startPage();
        List<TcZxyh> list = tcZxyhService.selectTcZxyhList(tcZxyh);
        return getDataTable(list);
    }

    /**
     * 导出最新隐患列表
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zxyh:export')")
    @Log(title = "最新隐患", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZxyh tcZxyh)
    {
        List<TcZxyh> list = tcZxyhService.selectTcZxyhList(tcZxyh);
        ExcelUtil<TcZxyh> util = new ExcelUtil<TcZxyh>(TcZxyh.class);
        util.exportExcel(response, list, "最新隐患数据");
    }

    /**
     * 获取最新隐患详细信息
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zxyh:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcZxyhService.selectTcZxyhById(id));
    }

    /**
     * 新增最新隐患
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zxyh:add')")
    @Log(title = "最新隐患", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcZxyh tcZxyh)
    {
        return toAjax(tcZxyhService.insertTcZxyh(tcZxyh));
    }

    /**
     * 修改最新隐患
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zxyh:edit')")
    @Log(title = "最新隐患", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcZxyh tcZxyh)
    {
        return toAjax(tcZxyhService.updateTcZxyh(tcZxyh));
    }

    /**
     * 删除最新隐患
     */
    @PreAuthorize("@ss.hasPermi('tcZz/networkSecurity:zxyh:remove')")
    @Log(title = "最新隐患", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcZxyhService.deleteTcZxyhByIds(ids));
    }
}
